"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPicker = void 0;
const material_1 = require("@mui/material");
const classnames_1 = __importDefault(require("classnames"));
const lodash_1 = require("lodash");
const hooks_1 = require("material-ui-popup-state/hooks");
const react_1 = __importDefault(require("react"));
const react_colorful_1 = require("react-colorful");
const react_hook_form_1 = require("react-hook-form");
const styles_1 = require("./styles");
const ColorPicker = ({ name, label, id, className, required = false, fieldRequiredText = "Required", validationErrorText = "Value must be a valid HEX color", placeholderText = "HEX Color", width, height, maxWidth, maxHeight, padding, margin, }) => {
    const { watch, setValue, formState: { errors }, } = (0, react_hook_form_1.useFormContext)();
    const popupState = (0, hooks_1.usePopupState)({
        variant: "popover",
        popupId: "colorPickerPopover",
    });
    const color = watch(name) || undefined;
    const classes = (0, styles_1.useColorPickerStyles)({
        color,
        width,
        height,
        maxWidth,
        maxHeight,
        padding,
        margin,
    });
    const validationRules = {
        required: required && fieldRequiredText,
        pattern: {
            value: /^#{1}([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/,
            message: validationErrorText,
        },
    };
    return (react_1.default.createElement(material_1.Box, { display: "flex", alignItems: "baseline", className: (0, classnames_1.default)(classes.root) },
        react_1.default.createElement(material_1.Popover, Object.assign({}, (0, hooks_1.bindPopover)(popupState), { anchorOrigin: {
                vertical: "bottom",
                horizontal: "left",
            }, transformOrigin: {
                vertical: "top",
                horizontal: "left",
            }, classes: { paper: classes.popoverPaper } }),
            react_1.default.createElement(react_colorful_1.HexColorPicker, { color: color, onChange: (value) => setValue(name, value, { shouldValidate: true }) })),
        react_1.default.createElement(material_1.Button, Object.assign({ variant: "contained" }, (0, hooks_1.bindTrigger)(popupState), { className: classes.pickerButton })),
        react_1.default.createElement(react_hook_form_1.Controller, { name: name, rules: validationRules, defaultValue: "", render: ({ field: { value, onChange } }) => {
                var _a;
                return (react_1.default.createElement(material_1.TextField, { error: !!(0, lodash_1.get)(errors, name), id: id, className: className, label: label, value: value, onChange: onChange, helperText: (_a = (0, lodash_1.get)(errors, name)) === null || _a === void 0 ? void 0 : _a.message, InputLabelProps: {
                        shrink: true,
                    }, placeholder: placeholderText }));
            } })));
};
exports.ColorPicker = ColorPicker;
//# sourceMappingURL=ColorPicker.js.map