import ExpandLess from "@mui/icons-material/ExpandLess";
import ExpandMore from "@mui/icons-material/ExpandMore";
import classNames from "classnames";
import React, { useCallback, useRef, useState } from "react";
import { useStyle } from "./styles";
import { AUTO, DEFAULT_BACKGROUND, DEFAULT_PRIMARY, DEFAULT_PRIMARY_HOVER, } from "../../constants/colors";
import { DEFAULT_BUTTON_ICON_SIZE, DEFAULT_CURSOR, DEFAULT_HEIGHT, DEFAULT_MARGIN, DEFAULT_PADDING, DEFAULT_WIDTH, } from "../../constants/defaultLayouts";
import { useOnClickOutside } from "../../hooks/useClickOutside";
export const Dropdown = ({ id, className, name, options = [], withCustomOption = false, selectedValue = "", withCustomSelectedValue = false, controlled = false, containerMargin = DEFAULT_MARGIN, containerPadding = DEFAULT_PADDING, containerWidth = DEFAULT_WIDTH, containerHeight = DEFAULT_HEIGHT, optionMargin = DEFAULT_MARGIN, optionPadding = DEFAULT_PADDING, optionWidth = DEFAULT_WIDTH, optionHeight = DEFAULT_HEIGHT, optionsContainerWidth = DEFAULT_WIDTH, optionsContainerHeight = AUTO, withArrow = true, labelText, labelBackgroundColor = DEFAULT_BACKGROUND, labelTextColor = DEFAULT_PRIMARY, backgroundColor = DEFAULT_BACKGROUND, textColor = DEFAULT_PRIMARY, selectedOptionBackgroundColor = DEFAULT_PRIMARY_HOVER, hoverOptionBackgroundColor = DEFAULT_BACKGROUND, hoverOptionTextColor = DEFAULT_PRIMARY, cursor = DEFAULT_CURSOR, onChange, onFocus, onBlur, }) => {
    const [isOpen, setIsOpen] = useState(false);
    const [value, setValue] = useState();
    const dropdownRef = useRef(null);
    const classes = useStyle({
        margin: containerMargin,
        padding: containerPadding,
        width: containerWidth,
        height: containerHeight,
        backgroundColor,
        textColor,
        cursor,
        labelBackgroundColor,
        labelTextColor,
        optionsContainerWidth,
        optionsContainerHeight,
        optionMargin,
        optionPadding,
        optionWidth,
        optionHeight,
        selectedOptionBackgroundColor,
        hoverOptionBackgroundColor,
        hoverOptionTextColor,
    });
    const handleClickOutside = useCallback(() => setIsOpen(false), []);
    useOnClickOutside(dropdownRef, handleClickOutside);
    if (controlled && !onChange) {
        console.warn("Controlled input requires onChance property");
    }
    const handleChange = useCallback((val) => {
        if (controlled) {
            onChange === null || onChange === void 0 ? void 0 : onChange(val.key);
        }
        else {
            setValue(val);
        }
    }, [controlled, onChange]);
    const toggleOpen = useCallback(() => {
        setIsOpen((prevIsOpen) => !prevIsOpen);
    }, []);
    return (React.createElement("div", { id: id, className: classNames(className, classes.container), onFocus: onFocus, onBlur: onBlur, onClick: toggleOpen, role: "presentation", ref: dropdownRef },
        labelText && (React.createElement("div", { className: classes.labelContainer },
            React.createElement("span", null, labelText))),
        React.createElement("div", { className: classes.dropdownContainer },
            withCustomSelectedValue ? (selectedValue) : (React.createElement("input", { className: classes.selectedValue, name: name, value: controlled ? selectedValue : value === null || value === void 0 ? void 0 : value.content, disabled: true })),
            withArrow &&
                (isOpen ? (React.createElement(ExpandLess, { width: DEFAULT_BUTTON_ICON_SIZE, height: DEFAULT_BUTTON_ICON_SIZE })) : (React.createElement(ExpandMore, { width: DEFAULT_BUTTON_ICON_SIZE, height: DEFAULT_BUTTON_ICON_SIZE })))),
        React.createElement("div", { className: classNames({ open: isOpen }, classes.optionContainer) }, withCustomOption
            ? options
            : options.map(({ key, content }) => (React.createElement("div", { key: key, className: classNames(key, {
                    selected: controlled
                        ? content === selectedValue
                        : key === (value === null || value === void 0 ? void 0 : value.key),
                }, classes.option), onClick: () => handleChange({ key, content }), role: "presentation" }, content))))));
};
//# sourceMappingURL=Dropdown.js.map