import Visibility from "@mui/icons-material/Visibility";
import VisibilityOff from "@mui/icons-material/VisibilityOff";
import { IconButton, InputAdornment, TextField } from "@mui/material";
import classNames from "classnames";
import React, { useCallback, useState } from "react";
import { Icon } from "../../Icon";
import { useStyle } from "../styles";
import { InputTypes } from "../types/inputTypes";
export const PasswordInput = ({ type, withShowHide = true, icon, iconSize, className, name, id, value, padding, margin, required, autoFocus, disabled, onChange, onFocus, onBlur, placeholder, error, errorBackgroundColor, errorTextColor, helperTextBackgroundColor, helperTextTextColor, textColor, labelText, helperText, defaultValue, }) => {
    const classes = useStyle({
        padding,
        margin,
        errorBackgroundColor,
        errorTextColor,
        textColor,
        helperTextBackgroundColor,
        helperTextTextColor,
    });
    const [isVisible, setVisibility] = useState(false);
    const inputType = withShowHide && isVisible ? InputTypes.TEXT : type;
    const toggleVisiblity = useCallback(() => setVisibility((prevVisiblity) => !prevVisiblity), []);
    return (React.createElement(TextField, { type: inputType, id: id, className: classNames(classes.root, className), name: name, value: value, required: required, 
        // eslint-disable-next-line jsx-a11y/no-autofocus
        autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: !!error, label: labelText, helperText: error ? error : helperText, defaultValue: defaultValue, InputProps: {
            className: classNames(classes.textColor),
            endAdornment: withShowHide && (React.createElement(InputAdornment, { position: "end" }, icon ? (React.createElement(Icon, { src: icon, onClick: toggleVisiblity, width: iconSize, height: iconSize })) : (React.createElement(IconButton, { "aria-label": "toggle password visibility", onClick: toggleVisiblity, edge: "end" }, isVisible ? React.createElement(VisibilityOff, null) : React.createElement(Visibility, null))))),
        }, FormHelperTextProps: Object.assign(Object.assign({}, (error && { className: classNames(classes.error) })), (!error &&
            helperText && { className: classNames(classes.helperText) })), InputLabelProps: Object.assign({}, (error && { className: classNames(classes.error) })) }));
};
//# sourceMappingURL=PasswordInput.js.map