import ExpandLess from "@mui/icons-material/ExpandLess";
import ExpandMore from "@mui/icons-material/ExpandMore";
import { Avatar, Collapse, Divider, ListItem, ListItemAvatar, ListItemIcon, ListItemSecondaryAction, ListItemText, ListSubheader, List as MuiList, } from "@mui/material";
import classNames from "classnames";
import React, { useState } from "react";
import { useStyle } from "./styles";
export const List = ({ id, className, width, height, maxWidth, maxHeight, padding, margin, border, borderRadius, outline, items = [], headerText, headerComponent, selected, backgroundColor, textColor, componentType = null, hoverBackgroundColor, hoverTextColor, }) => {
    const [isOpen, setIsOpen] = useState([]);
    const handleOpenCollapsable = (level) => {
        setIsOpen((prevIsOpen) => [
            ...prevIsOpen.slice(0, level),
            !prevIsOpen[level],
            ...prevIsOpen.slice(level + 1),
        ]);
    };
    const classes = useStyle({
        width,
        height,
        maxWidth,
        maxHeight,
        padding,
        margin,
        border,
        borderRadius,
        outline,
        backgroundColor,
        textColor,
        hoverBackgroundColor,
        hoverTextColor,
    });
    const listHeaderComponent = headerComponent ? (React.createElement(ListSubheader, { component: "div" }, headerComponent)) : headerText ? (React.createElement(ListSubheader, { component: "div" }, headerText)) : null;
    const renderList = (nestingLevel = 0, items, isNested) => items ? (React.createElement(MuiList, Object.assign({ className: classNames(classes.root, isNested ? classes.nested : "", className) }, (nestingLevel === 0 && { id }), (componentType && { component: componentType }), (listHeaderComponent &&
        nestingLevel === 0 && { subheader: listHeaderComponent })), items.map((item, index) => {
        const nestedList = renderList(nestingLevel + 1, item.nestedItems, true);
        if (item.isButtonType) {
            const listItemOnClick = (item.nestedItems || []).length > 0
                ? {
                    onClick: () => handleOpenCollapsable(nestingLevel),
                }
                : item.onClick && {
                    onClick: item.onClick,
                };
            return (React.createElement(React.Fragment, { key: `${nestingLevel}_${index}` },
                React.createElement(ListItem, Object.assign({ button: true, className: "list-item" }, listItemOnClick, { selected: nestingLevel === 0 && selected === index }, (item.alignItems && { alignItems: item.alignItems })),
                    item.startIcon && item.withAvatar ? (React.createElement(ListItemAvatar, null,
                        React.createElement(Avatar, null, item.startIcon))) : (React.createElement(ListItemIcon, null, item.startIcon)),
                    (item.primaryText || item.secondaryText) && (React.createElement(ListItemText, { primary: item.primaryText, secondary: item.secondaryText, inset: item.inset })),
                    item.secondaryAction && (React.createElement(ListItemSecondaryAction, null, item.secondaryAction)),
                    (item.nestedItems || []).length > 0 &&
                        item.withCollapsableIcon &&
                        (isOpen[nestingLevel] ? React.createElement(ExpandLess, null) : React.createElement(ExpandMore, null))),
                item.withDeviderAfter && React.createElement(Divider, null),
                nestedList && (React.createElement(Collapse, { in: isOpen[nestingLevel], timeout: "auto", unmountOnExit: true }, nestedList))));
        }
        else {
            return (React.createElement(React.Fragment, { key: `${nestingLevel}_${index}` },
                React.createElement(ListItem, Object.assign({ className: "list-item" }, ((item.nestedItems || []).length > 0 && {
                    onClick: () => handleOpenCollapsable(nestingLevel),
                }), { selected: nestingLevel === 0 && selected === index }),
                    item.startIcon && item.withAvatar ? (React.createElement(ListItemAvatar, null,
                        React.createElement(Avatar, null, item.startIcon))) : (React.createElement(ListItemIcon, null, item.startIcon)),
                    (item.primaryText || item.secondaryText) && (React.createElement(ListItemText, { primary: item.primaryText, secondary: item.secondaryText })),
                    item.secondaryAction && (React.createElement(ListItemSecondaryAction, null, item.secondaryAction)),
                    (item.nestedItems || []).length > 0 &&
                        item.withCollapsableIcon &&
                        (isOpen[nestingLevel] ? React.createElement(ExpandLess, null) : React.createElement(ExpandMore, null))),
                nestedList && (React.createElement(Collapse, { in: isOpen[nestingLevel], timeout: "auto", unmountOnExit: true }, nestedList))));
        }
    }))) : null;
    return renderList(0, items, false);
};
//# sourceMappingURL=List.js.map